Report

Go to page content

# Dexy Run Report

## Results of your Run

This is a logfile to help you understand how dexy has processed your files and to assist with troubleshooting.

### Timing

The total elapsed time for batch 1004 was 2.45 (0.04 minutes).

### Config

This is the configuration which was used for this run:

    Directory .:
    code:
        - .R|rout

    .md|jinja|pandoc:
        - code

    .md|jinja|pandoc|-odt:
        - pandoc: { ext : .odt }
        - code

    .md|jinja|pandoc|-pdf:
        - pandoc: { ext : .pdf }
        - code

    .md|jinja|pandoc|-docx:
        - pandoc: { ext : .docx }
        - code

    .md|jinja|pandoc|-epub:
        - pandoc: { ext : .epub }
        - code

    .md|jinja|pandoc|calibre:
        - code

# 10 Slowest Tasks

- 1.748 - report.md|jinja|pandoc|calibre (generated)
- 0.077 - report.md|jinja|pandoc (generated)
- 0.038 - report.md|jinja (generated)
- 0.009 - example.R|rout (cached)
- 0.001 - report.md|jinja (cached)
- 0.001 - report.md|jinja|pandoc (cached)
- 0.001 - report.md|jinja (cached)
- 0.001 - report.md|jinja|pandoc (cached)
- 0.001 - report.md|jinja (cached)
- 0.001 - report.md|jinja (cached)

# Documents

## example.R|rout ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
example.R | artifacts/37efdae66ef5056d41883121456b3c86.R | 0.0001 |  |  |
example.R|rout | artifacts/db00c9d7c68b1858edb98ddfff3140fb.txt | 0.0086 | cached |  | wd

#### Document Log

    2012-11-24 13:38:43,761 - example.R|rout - DEBUG - Setting up FilterArtifact:example.R|rout::Doc:example.R|rout
    2012-11-24 13:38:43,782 - example.R|rout - DEBUG - Setting hashstring for example.R|rout to db00c9d7c68b1858edb98ddfff3140fb
    2012-11-24 13:38:43,783 - example.R|rout - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,103 - example.R|rout - DEBUG - Running FilterArtifact:example.R|rout::Doc:example.R|rout
    2012-11-24 13:38:44,103 - example.R|rout - DEBUG - Output is cached under db00c9d7c68b1858edb98ddfff3140fb, reconstituting...
    2012-11-24 13:38:44,105 - example.R|rout - DEBUG - Reconstituting example.txt from database and cache
    2012-11-24 13:38:44,106 - example.R|rout - DEBUG - adding additional doc example.txt (created by example.R|rout)
    2012-11-24 13:38:44,109 - example.R|rout - DEBUG - Reconstituting example.txt from database and cache
    2012-11-24 13:38:44,109 - example.R|rout - DEBUG - Reconstituting plot.png from database and cache
    2012-11-24 13:38:44,109 - example.R|rout - DEBUG - adding additional doc plot.png (created by example.R|rout)
    2012-11-24 13:38:44,110 - example.R|rout - DEBUG - Reconstituting plot.png from database and cache
    2012-11-24 13:38:44,110 - example.R|rout - DEBUG - Reconstituting storage.json from database and cache
    2012-11-24 13:38:44,110 - example.R|rout - DEBUG - adding additional doc storage.json (created by example.R|rout)
    2012-11-24 13:38:44,111 - example.R|rout - DEBUG - Reconstituting storage.json from database and cache

## report.md|jinja|pandoc ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/3b51ad54d83e46c731e15d04028b1298.md | 0.0007 | cached |  | wd
report.md|jinja|pandoc | artifacts/56ee4f9438b2be075327e5126137ce95.html | 0.0006 | cached |  | wd

#### Document Log

    2012-11-24 13:38:43,797 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,798 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,812 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:38:43,813 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,816 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,819 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,836 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to aa79acb1dcf9be1344c44222c137cea5
    2012-11-24 13:38:43,838 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,983 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:43,986 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:38:43,987 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,988 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,002 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:38:44,004 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,011 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,013 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,027 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:38:44,033 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,042 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,045 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:38:44,046 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,047 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,062 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:38:44,064 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,072 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,074 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:38:44,076 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,077 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,094 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:38:44,096 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,112 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja - DEBUG - Output is cached under 3b51ad54d83e46c731e15d04028b1298, reconstituting...
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Output is cached under 56ee4f9438b2be075327e5126137ce95, reconstituting...
    2012-11-24 13:38:44,114 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - Output is not cached under bd583aed7fddb0942175f09553c8d9da, running...
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/bd583aed7fddb0942175f09553c8d9da/
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/bd583aed7fddb0942175f09553c8d9da/, artifacts/bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:38:44,148 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:38:44,151 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Output is not cached under aa79acb1dcf9be1344c44222c137cea5, running...
    2012-11-24 13:38:44,153 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/aa79acb1dcf9be1344c44222c137cea5/
    2012-11-24 13:38:44,154 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/aa79acb1dcf9be1344c44222c137cea5/'
    2012-11-24 13:38:44,225 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:38:44,227 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:38:45,980 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,981 - report.md|jinja - DEBUG - Output is cached under d781adeca229bf3c204d4559e7142f82, reconstituting...
    2012-11-24 13:38:45,981 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc - DEBUG - Output is cached under 5e3fd51d5ca109fcd8ea025ec8812a58, reconstituting...
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Output is cached under 268ddcdbbb07b992279bfee51f3fc10a, reconstituting...
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Output is cached under b27f64993498e575dfb34cb451b98a60, reconstituting...
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Output is cached under b93ce2270e0bca12beabeb94273e155c, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Output is cached under 9a2ebc0b68c10b24f3373072e135983a, reconstituting...
    2012-11-24 13:38:45,988 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,989 - report.md|jinja - DEBUG - Output is cached under f143a1cc23ee4ca0350b69101644bfe2, reconstituting...
    2012-11-24 13:38:45,989 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc - DEBUG - Output is cached under 5a19c3f5c58a1f5da222674b87c237ed, reconstituting...

## report.md|jinja|pandoc|calibre ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/bd583aed7fddb0942175f09553c8d9da.md | 0.0377 | generated |  | wd
report.md|jinja|pandoc | artifacts/aa79acb1dcf9be1344c44222c137cea5.epub | 0.0772 | generated |  | wd
report.md|jinja|pandoc|calibre | artifacts/9b02bc4cfa7041614012c0435749c375.mobi | 1.7477 | generated |  | wd

#### Document Log

    2012-11-24 13:38:43,797 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,798 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,812 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:38:43,813 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,816 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,819 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,836 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to aa79acb1dcf9be1344c44222c137cea5
    2012-11-24 13:38:43,838 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,839 - report.md|jinja|pandoc|calibre - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|calibre::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,978 - report.md|jinja|pandoc|calibre - DEBUG - Setting hashstring for report.md|jinja|pandoc|calibre to 9b02bc4cfa7041614012c0435749c375
    2012-11-24 13:38:43,979 - report.md|jinja|pandoc|calibre - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,983 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:43,986 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:38:43,987 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,988 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,002 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:38:44,004 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,011 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,013 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,027 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:38:44,033 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,042 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,045 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:38:44,046 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,047 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,062 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:38:44,064 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,072 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,074 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:38:44,076 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,077 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,094 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:38:44,096 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,112 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja - DEBUG - Output is cached under 3b51ad54d83e46c731e15d04028b1298, reconstituting...
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Output is cached under 56ee4f9438b2be075327e5126137ce95, reconstituting...
    2012-11-24 13:38:44,114 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - Output is not cached under bd583aed7fddb0942175f09553c8d9da, running...
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/bd583aed7fddb0942175f09553c8d9da/
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/bd583aed7fddb0942175f09553c8d9da/, artifacts/bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:38:44,148 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:38:44,151 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Output is not cached under aa79acb1dcf9be1344c44222c137cea5, running...
    2012-11-24 13:38:44,153 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/aa79acb1dcf9be1344c44222c137cea5/
    2012-11-24 13:38:44,154 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/aa79acb1dcf9be1344c44222c137cea5/'
    2012-11-24 13:38:44,225 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:38:44,227 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:38:44,230 - report.md|jinja|pandoc|calibre - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|calibre::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,231 - report.md|jinja|pandoc|calibre - DEBUG - Output is not cached under 9b02bc4cfa7041614012c0435749c375, running...
    2012-11-24 13:38:44,233 - report.md|jinja|pandoc|calibre - DEBUG - setting up wd for report.md|jinja|pandoc|calibre. exists already: artifacts/9b02bc4cfa7041614012c0435749c375/
    2012-11-24 13:38:44,236 - report.md|jinja|pandoc|calibre - DEBUG - about to run 'ebook-convert report.epub report.mobi ' in 'artifacts/9b02bc4cfa7041614012c0435749c375/'
    2012-11-24 13:38:45,964 - report.md|jinja|pandoc|calibre - DEBUG - stdout is '1% Converting input to HTML...
    InputFormatPlugin: EPUB Input running
    on /home/ana/dev/dexy-templates/dexy_templates/pander-template/artifacts/9b02bc4cfa7041614012c0435749c375/report.epub
    Parsing all content...
    34% Running transforms on ebook...
    Merging user specified metadata...
    Detecting structure...
    Flattening CSS and remapping font sizes...
    Source base font size is 12.00000pt
    Removing fake margins...
    Cleaning up manifest...
    Trimming unused files from manifest...
    Creating MOBI Output...
    67% Running MOBI Output plugin
    Serializing resources...
    Creating MOBI 6 output
    Generating in-line TOC...
    Applying case-transforming CSS...
    Rasterizing SVG images...
    Converting XHTML to Mobipocket markup...
    Serializing markup content...
      Compressing markup content...
    Generating MOBI index for a book
    MOBI output written to /home/ana/dev/dexy-templates/dexy_templates/pander-template/artifacts/9b02bc4cfa7041614012c0435749c375/report.mobi
    Output saved to   /home/ana/dev/dexy-templates/dexy_templates/pander-template/artifacts/9b02bc4cfa7041614012c0435749c375/report.mobi
    '
    2012-11-24 13:38:45,965 - report.md|jinja|pandoc|calibre - DEBUG - stderr is ''
    2012-11-24 13:38:45,966 - report.md|jinja|pandoc|calibre - DEBUG - adding new files found in artifacts/9b02bc4cfa7041614012c0435749c375 for report.md|jinja|pandoc|calibre
    2012-11-24 13:38:45,968 - report.md|jinja|pandoc|calibre - DEBUG - adding additional doc report.epub (created by report.md|jinja|pandoc|calibre)
    2012-11-24 13:38:45,974 - report.md|jinja|pandoc|calibre - DEBUG - adding additional doc report.mobi (created by report.md|jinja|pandoc|calibre)
    2012-11-24 13:38:45,980 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,981 - report.md|jinja - DEBUG - Output is cached under d781adeca229bf3c204d4559e7142f82, reconstituting...
    2012-11-24 13:38:45,981 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc - DEBUG - Output is cached under 5e3fd51d5ca109fcd8ea025ec8812a58, reconstituting...
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Output is cached under 268ddcdbbb07b992279bfee51f3fc10a, reconstituting...
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Output is cached under b27f64993498e575dfb34cb451b98a60, reconstituting...
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Output is cached under b93ce2270e0bca12beabeb94273e155c, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Output is cached under 9a2ebc0b68c10b24f3373072e135983a, reconstituting...
    2012-11-24 13:38:45,988 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,989 - report.md|jinja - DEBUG - Output is cached under f143a1cc23ee4ca0350b69101644bfe2, reconstituting...
    2012-11-24 13:38:45,989 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc - DEBUG - Output is cached under 5a19c3f5c58a1f5da222674b87c237ed, reconstituting...

## report.md|jinja|pandoc|-odt ↑

#### Arguments

    pandoc:
        ext: .odt

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/d781adeca229bf3c204d4559e7142f82.md | 0.0008 | cached |  | wd
report.md|jinja|pandoc | artifacts/5e3fd51d5ca109fcd8ea025ec8812a58.odt | 0.0007 | cached |  | wd
report.md|jinja|pandoc|-odt | artifacts/abc9513aa869aba5c54d4f7bd5fb212a.odt | 0.0004 | cached |  |

#### Document Log

    2012-11-24 13:38:43,797 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,798 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,812 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:38:43,813 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,816 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,819 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,836 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to aa79acb1dcf9be1344c44222c137cea5
    2012-11-24 13:38:43,838 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,983 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:43,986 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:38:43,987 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,988 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,002 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:38:44,004 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,005 - report.md|jinja|pandoc|-odt - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-odt::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,007 - report.md|jinja|pandoc|-odt - DEBUG - Setting hashstring for report.md|jinja|pandoc|-odt to abc9513aa869aba5c54d4f7bd5fb212a
    2012-11-24 13:38:44,008 - report.md|jinja|pandoc|-odt - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,011 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,013 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,027 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:38:44,033 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,042 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,045 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:38:44,046 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,047 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,062 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:38:44,064 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,072 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,074 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:38:44,076 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,077 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,094 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:38:44,096 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,112 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja - DEBUG - Output is cached under 3b51ad54d83e46c731e15d04028b1298, reconstituting...
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Output is cached under 56ee4f9438b2be075327e5126137ce95, reconstituting...
    2012-11-24 13:38:44,114 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - Output is not cached under bd583aed7fddb0942175f09553c8d9da, running...
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/bd583aed7fddb0942175f09553c8d9da/
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/bd583aed7fddb0942175f09553c8d9da/, artifacts/bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:38:44,148 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:38:44,151 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Output is not cached under aa79acb1dcf9be1344c44222c137cea5, running...
    2012-11-24 13:38:44,153 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/aa79acb1dcf9be1344c44222c137cea5/
    2012-11-24 13:38:44,154 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/aa79acb1dcf9be1344c44222c137cea5/'
    2012-11-24 13:38:44,225 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:38:44,227 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:38:45,980 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,981 - report.md|jinja - DEBUG - Output is cached under d781adeca229bf3c204d4559e7142f82, reconstituting...
    2012-11-24 13:38:45,981 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc - DEBUG - Output is cached under 5e3fd51d5ca109fcd8ea025ec8812a58, reconstituting...
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc|-odt - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-odt::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc|-odt - DEBUG - Output is cached under abc9513aa869aba5c54d4f7bd5fb212a, reconstituting...
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Output is cached under 268ddcdbbb07b992279bfee51f3fc10a, reconstituting...
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Output is cached under b27f64993498e575dfb34cb451b98a60, reconstituting...
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Output is cached under b93ce2270e0bca12beabeb94273e155c, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Output is cached under 9a2ebc0b68c10b24f3373072e135983a, reconstituting...
    2012-11-24 13:38:45,988 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,989 - report.md|jinja - DEBUG - Output is cached under f143a1cc23ee4ca0350b69101644bfe2, reconstituting...
    2012-11-24 13:38:45,989 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc - DEBUG - Output is cached under 5a19c3f5c58a1f5da222674b87c237ed, reconstituting...

## report.md|jinja|pandoc|-epub ↑

#### Arguments

    pandoc:
        ext: .epub

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/268ddcdbbb07b992279bfee51f3fc10a.md | 0.0007 | cached |  | wd
report.md|jinja|pandoc | artifacts/b27f64993498e575dfb34cb451b98a60.epub | 0.0007 | cached |  | wd
report.md|jinja|pandoc|-epub | artifacts/9f6b0ac9c642cc52dcb00a5996eec4ba.epub | 0.0004 | cached |  |

#### Document Log

    2012-11-24 13:38:43,797 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,798 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,812 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:38:43,813 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,816 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,819 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,836 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to aa79acb1dcf9be1344c44222c137cea5
    2012-11-24 13:38:43,838 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,983 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:43,986 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:38:43,987 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,988 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,002 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:38:44,004 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,011 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,013 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,027 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:38:44,033 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,035 - report.md|jinja|pandoc|-epub - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-epub::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,037 - report.md|jinja|pandoc|-epub - DEBUG - Setting hashstring for report.md|jinja|pandoc|-epub to 9f6b0ac9c642cc52dcb00a5996eec4ba
    2012-11-24 13:38:44,038 - report.md|jinja|pandoc|-epub - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,042 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,045 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:38:44,046 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,047 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,062 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:38:44,064 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,072 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,074 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:38:44,076 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,077 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,094 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:38:44,096 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,112 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja - DEBUG - Output is cached under 3b51ad54d83e46c731e15d04028b1298, reconstituting...
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Output is cached under 56ee4f9438b2be075327e5126137ce95, reconstituting...
    2012-11-24 13:38:44,114 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - Output is not cached under bd583aed7fddb0942175f09553c8d9da, running...
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/bd583aed7fddb0942175f09553c8d9da/
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/bd583aed7fddb0942175f09553c8d9da/, artifacts/bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:38:44,148 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:38:44,151 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Output is not cached under aa79acb1dcf9be1344c44222c137cea5, running...
    2012-11-24 13:38:44,153 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/aa79acb1dcf9be1344c44222c137cea5/
    2012-11-24 13:38:44,154 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/aa79acb1dcf9be1344c44222c137cea5/'
    2012-11-24 13:38:44,225 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:38:44,227 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:38:45,980 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,981 - report.md|jinja - DEBUG - Output is cached under d781adeca229bf3c204d4559e7142f82, reconstituting...
    2012-11-24 13:38:45,981 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc - DEBUG - Output is cached under 5e3fd51d5ca109fcd8ea025ec8812a58, reconstituting...
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Output is cached under 268ddcdbbb07b992279bfee51f3fc10a, reconstituting...
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Output is cached under b27f64993498e575dfb34cb451b98a60, reconstituting...
    2012-11-24 13:38:45,985 - report.md|jinja|pandoc|-epub - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-epub::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,985 - report.md|jinja|pandoc|-epub - DEBUG - Output is cached under 9f6b0ac9c642cc52dcb00a5996eec4ba, reconstituting...
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Output is cached under b93ce2270e0bca12beabeb94273e155c, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Output is cached under 9a2ebc0b68c10b24f3373072e135983a, reconstituting...
    2012-11-24 13:38:45,988 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,989 - report.md|jinja - DEBUG - Output is cached under f143a1cc23ee4ca0350b69101644bfe2, reconstituting...
    2012-11-24 13:38:45,989 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc - DEBUG - Output is cached under 5a19c3f5c58a1f5da222674b87c237ed, reconstituting...

## report.md|jinja|pandoc|-pdf ↑

#### Arguments

    pandoc:
        ext: .pdf

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/b93ce2270e0bca12beabeb94273e155c.md | 0.0007 | cached |  | wd
report.md|jinja|pandoc | artifacts/9a2ebc0b68c10b24f3373072e135983a.pdf | 0.0007 | cached |  | wd
report.md|jinja|pandoc|-pdf | artifacts/dd20b3681eff2a48ec03888ef2adfc12.pdf | 0.0004 | cached |  |

#### Document Log

    2012-11-24 13:38:43,797 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,798 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,812 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:38:43,813 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,816 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,819 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,836 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to aa79acb1dcf9be1344c44222c137cea5
    2012-11-24 13:38:43,838 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,983 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:43,986 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:38:43,987 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,988 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,002 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:38:44,004 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,011 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,013 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,027 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:38:44,033 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,042 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,045 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:38:44,046 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,047 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,062 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:38:44,064 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,065 - report.md|jinja|pandoc|-pdf - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-pdf::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,067 - report.md|jinja|pandoc|-pdf - DEBUG - Setting hashstring for report.md|jinja|pandoc|-pdf to dd20b3681eff2a48ec03888ef2adfc12
    2012-11-24 13:38:44,068 - report.md|jinja|pandoc|-pdf - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,072 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,074 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:38:44,076 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,077 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,094 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:38:44,096 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,112 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja - DEBUG - Output is cached under 3b51ad54d83e46c731e15d04028b1298, reconstituting...
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Output is cached under 56ee4f9438b2be075327e5126137ce95, reconstituting...
    2012-11-24 13:38:44,114 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - Output is not cached under bd583aed7fddb0942175f09553c8d9da, running...
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/bd583aed7fddb0942175f09553c8d9da/
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/bd583aed7fddb0942175f09553c8d9da/, artifacts/bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:38:44,148 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:38:44,151 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Output is not cached under aa79acb1dcf9be1344c44222c137cea5, running...
    2012-11-24 13:38:44,153 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/aa79acb1dcf9be1344c44222c137cea5/
    2012-11-24 13:38:44,154 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/aa79acb1dcf9be1344c44222c137cea5/'
    2012-11-24 13:38:44,225 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:38:44,227 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:38:45,980 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,981 - report.md|jinja - DEBUG - Output is cached under d781adeca229bf3c204d4559e7142f82, reconstituting...
    2012-11-24 13:38:45,981 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc - DEBUG - Output is cached under 5e3fd51d5ca109fcd8ea025ec8812a58, reconstituting...
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Output is cached under 268ddcdbbb07b992279bfee51f3fc10a, reconstituting...
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Output is cached under b27f64993498e575dfb34cb451b98a60, reconstituting...
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Output is cached under b93ce2270e0bca12beabeb94273e155c, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Output is cached under 9a2ebc0b68c10b24f3373072e135983a, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc|-pdf - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-pdf::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,988 - report.md|jinja|pandoc|-pdf - DEBUG - Output is cached under dd20b3681eff2a48ec03888ef2adfc12, reconstituting...
    2012-11-24 13:38:45,988 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,989 - report.md|jinja - DEBUG - Output is cached under f143a1cc23ee4ca0350b69101644bfe2, reconstituting...
    2012-11-24 13:38:45,989 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc - DEBUG - Output is cached under 5a19c3f5c58a1f5da222674b87c237ed, reconstituting...

## report.md|jinja|pandoc|-docx ↑

#### Arguments

    pandoc:
        ext: .docx

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.md | artifacts/ba4b4eac4cc67bdfe501b9d6c91c4948.md | 0.0000 |  |  |
report.md|jinja | artifacts/f143a1cc23ee4ca0350b69101644bfe2.md | 0.0007 | cached |  | wd
report.md|jinja|pandoc | artifacts/5a19c3f5c58a1f5da222674b87c237ed.docx | 0.0007 | cached |  | wd
report.md|jinja|pandoc|-docx | artifacts/de75484514388939aa97dd3f00993cb4.docx | 0.0004 | cached |  |

#### Document Log

    2012-11-24 13:38:43,797 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 3b51ad54d83e46c731e15d04028b1298
    2012-11-24 13:38:43,798 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,798 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:43,812 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 56ee4f9438b2be075327e5126137ce95
    2012-11-24 13:38:43,813 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,816 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:43,818 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,819 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:43,836 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to aa79acb1dcf9be1344c44222c137cea5
    2012-11-24 13:38:43,838 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,983 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:43,986 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to d781adeca229bf3c204d4559e7142f82
    2012-11-24 13:38:43,987 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:43,988 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:44,002 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5e3fd51d5ca109fcd8ea025ec8812a58
    2012-11-24 13:38:44,004 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,011 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to 268ddcdbbb07b992279bfee51f3fc10a
    2012-11-24 13:38:44,013 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,013 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:44,027 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to b27f64993498e575dfb34cb451b98a60
    2012-11-24 13:38:44,033 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,042 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,045 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to b93ce2270e0bca12beabeb94273e155c
    2012-11-24 13:38:44,046 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,047 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:44,062 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 9a2ebc0b68c10b24f3373072e135983a
    2012-11-24 13:38:44,064 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,072 - report.md|jinja - DEBUG - Setting up FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,074 - report.md|jinja - DEBUG - Setting hashstring for report.md|jinja to f143a1cc23ee4ca0350b69101644bfe2
    2012-11-24 13:38:44,076 - report.md|jinja - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,077 - report.md|jinja|pandoc - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,094 - report.md|jinja|pandoc - DEBUG - Setting hashstring for report.md|jinja|pandoc to 5a19c3f5c58a1f5da222674b87c237ed
    2012-11-24 13:38:44,096 - report.md|jinja|pandoc - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,098 - report.md|jinja|pandoc|-docx - DEBUG - Setting up FilterArtifact:report.md|jinja|pandoc|-docx::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:44,100 - report.md|jinja|pandoc|-docx - DEBUG - Setting hashstring for report.md|jinja|pandoc|-docx to de75484514388939aa97dd3f00993cb4
    2012-11-24 13:38:44,100 - report.md|jinja|pandoc|-docx - DEBUG - setting up output data of class GenericData
    2012-11-24 13:38:44,112 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja - DEBUG - Output is cached under 3b51ad54d83e46c731e15d04028b1298, reconstituting...
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc
    2012-11-24 13:38:44,113 - report.md|jinja|pandoc - DEBUG - Output is cached under 56ee4f9438b2be075327e5126137ce95, reconstituting...
    2012-11-24 13:38:44,114 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - Output is not cached under bd583aed7fddb0942175f09553c8d9da, running...
    2012-11-24 13:38:44,115 - report.md|jinja - DEBUG - setting up wd for report.md|jinja. exists already: artifacts/bd583aed7fddb0942175f09553c8d9da/
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja FileSystemLoader with dirs ., artifacts/bd583aed7fddb0942175f09553c8d9da/, artifacts/bd583aed7fddb0942175f09553c8d9da
    2012-11-24 13:38:44,116 - report.md|jinja - DEBUG - setting up jinja environment
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Creating jinja2 environment with: undefined: , loader:
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - initializing template
    2012-11-24 13:38:44,117 - report.md|jinja - DEBUG - Running template plugin PrettyPrintJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PythonDatetime
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin DexyVersion
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin SimpleJson
    2012-11-24 13:38:44,118 - report.md|jinja - DEBUG - Running template plugin PrettyPrinter
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin RegularExpressions
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PythonBuiltins
    2012-11-24 13:38:44,119 - report.md|jinja - DEBUG - Running template plugin PygmentsStylesheet
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Subdirectories
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Variables
    2012-11-24 13:38:44,146 - report.md|jinja - DEBUG - Running template plugin Globals
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - Running template plugin Inputs
    2012-11-24 13:38:44,147 - report.md|jinja - DEBUG - jinja template data keys are DEXY_VERSION, a, abs, all, any, bin, bool, bytearray, cal, caldates, calendar, callable, chr, cmp, complex, d, datetime, dict, dir, divmod, enumerate, f, filter, float, format, hasattr, hex, highlight, id, int, isinstance, issubclass, iter, json, len, list, long, map, max, min, month, oct, ord, pformat, pow, ppjson, pygments, range, re_match, re_search, reduce, repr, reversed, round, s, set, slice, sorted, str, subdirectories, sum, tc, today, tuple, unicode, w, xrange, year, zip
    2012-11-24 13:38:44,148 - report.md|jinja - DEBUG - about to create jinja template
    2012-11-24 13:38:44,151 - report.md|jinja - DEBUG - about to process jinja template
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|calibre
    2012-11-24 13:38:44,152 - report.md|jinja|pandoc - DEBUG - Output is not cached under aa79acb1dcf9be1344c44222c137cea5, running...
    2012-11-24 13:38:44,153 - report.md|jinja|pandoc - DEBUG - setting up wd for report.md|jinja|pandoc. exists already: artifacts/aa79acb1dcf9be1344c44222c137cea5/
    2012-11-24 13:38:44,154 - report.md|jinja|pandoc - DEBUG - about to run 'pandoc  report.md -o report.epub' in 'artifacts/aa79acb1dcf9be1344c44222c137cea5/'
    2012-11-24 13:38:44,225 - report.md|jinja|pandoc - DEBUG - stdout is ''
    2012-11-24 13:38:44,227 - report.md|jinja|pandoc - DEBUG - stderr is ''
    2012-11-24 13:38:45,980 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,981 - report.md|jinja - DEBUG - Output is cached under d781adeca229bf3c204d4559e7142f82, reconstituting...
    2012-11-24 13:38:45,981 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-odt
    2012-11-24 13:38:45,982 - report.md|jinja|pandoc - DEBUG - Output is cached under 5e3fd51d5ca109fcd8ea025ec8812a58, reconstituting...
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,983 - report.md|jinja - DEBUG - Output is cached under 268ddcdbbb07b992279bfee51f3fc10a, reconstituting...
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-epub
    2012-11-24 13:38:45,984 - report.md|jinja|pandoc - DEBUG - Output is cached under b27f64993498e575dfb34cb451b98a60, reconstituting...
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,986 - report.md|jinja - DEBUG - Output is cached under b93ce2270e0bca12beabeb94273e155c, reconstituting...
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-pdf
    2012-11-24 13:38:45,987 - report.md|jinja|pandoc - DEBUG - Output is cached under 9a2ebc0b68c10b24f3373072e135983a, reconstituting...
    2012-11-24 13:38:45,988 - report.md|jinja - DEBUG - Running FilterArtifact:report.md|jinja::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,989 - report.md|jinja - DEBUG - Output is cached under f143a1cc23ee4ca0350b69101644bfe2, reconstituting...
    2012-11-24 13:38:45,989 - report.md|jinja|pandoc - DEBUG - Running FilterArtifact:report.md|jinja|pandoc::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc - DEBUG - Output is cached under 5a19c3f5c58a1f5da222674b87c237ed, reconstituting...
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc|-docx - DEBUG - Running FilterArtifact:report.md|jinja|pandoc|-docx::Doc:report.md|jinja|pandoc|-docx
    2012-11-24 13:38:45,990 - report.md|jinja|pandoc|-docx - DEBUG - Output is cached under de75484514388939aa97dd3f00993cb4, reconstituting...

## example.txt ↑

#### Arguments

    data-class-alias: generic
    contentshash: 8d6e60b92afeccea5db97d109b0f9324

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
example.txt | artifacts/67ca147287010eee7af5529b040a79ab.txt | 0.0000 |  |  |

#### Document Log

    2012-11-24 13:38:44,107 - example.txt - DEBUG - Setting up InitialVirtualArtifact:example.txt::Doc:example.txt
    2012-11-24 13:38:44,108 - example.txt - DEBUG - Setting hashstring for example.txt to 67ca147287010eee7af5529b040a79ab
    2012-11-24 13:38:44,108 - example.txt - DEBUG - setting up output data of class GenericData

## plot.png ↑

#### Arguments

    data-class-alias: generic
    contentshash: 5428acf7feb0ca49cfdbeceb1ed9d68b

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
plot.png | artifacts/2fcd6e22786b435da431867dbef1647e.png | 0.0000 |  |  |

#### Document Log

    2012-11-24 13:38:44,109 - plot.png - DEBUG - Setting up InitialVirtualArtifact:plot.png::Doc:plot.png
    2012-11-24 13:38:44,109 - plot.png - DEBUG - Setting hashstring for plot.png to 2fcd6e22786b435da431867dbef1647e
    2012-11-24 13:38:44,110 - plot.png - DEBUG - setting up output data of class GenericData

## storage.json ↑

#### Arguments

    data-class-alias: generic
    contentshash: bdf66404568144153b47135bedb6f2ea

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
storage.json | artifacts/dcebc4433e4a66776a1573a5bc232c98.json | 0.0000 |  |  |

#### Document Log

    2012-11-24 13:38:44,111 - storage.json - DEBUG - Setting up InitialVirtualArtifact:storage.json::Doc:storage.json
    2012-11-24 13:38:44,111 - storage.json - DEBUG - Setting hashstring for storage.json to dcebc4433e4a66776a1573a5bc232c98
    2012-11-24 13:38:44,111 - storage.json - DEBUG - setting up output data of class GenericData

## report.epub ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.epub | artifacts/d4c54c176c65ada9b81bcdee2de44f91.epub | 0.0001 |  |  |

#### Document Log

    2012-11-24 13:38:45,969 - report.epub - DEBUG - Setting up InitialVirtualArtifact:report.epub::Doc:report.epub
    2012-11-24 13:38:45,970 - report.epub - DEBUG - Setting hashstring for report.epub to d4c54c176c65ada9b81bcdee2de44f91
    2012-11-24 13:38:45,970 - report.epub - DEBUG - setting up output data of class GenericData

## report.mobi ↑

#### Arguments

#### Artifacts

Key | Link | Elapsed | Run Type | Sections | wd
--- | --- | --- | --- | --- | ---
report.mobi | artifacts/409ac5ee3781b22e159cccc5daa1594c.mobi | 0.0001 |  |  |

#### Document Log

    2012-11-24 13:38:45,975 - report.mobi - DEBUG - Setting up InitialVirtualArtifact:report.mobi::Doc:report.mobi
    2012-11-24 13:38:45,976 - report.mobi - DEBUG - Setting hashstring for report.mobi to 409ac5ee3781b22e159cccc5daa1594c
    2012-11-24 13:38:45,976 - report.mobi - DEBUG - setting up output data of class GenericData